Index: /FCKeditor/trunk/_whatsnew.html
===================================================================
--- /FCKeditor/trunk/_whatsnew.html	(revision 207)
+++ /FCKeditor/trunk/_whatsnew.html	(revision 208)
@@ -108,4 +108,7 @@
 		<li>[<a target="_blank" href="http://dev.fckeditor.net/ticket/213">#213</a>] Styles
 			are now preserved when hitting enter at the end of a paragraph.</li>
+		<li>[<a target="_blank" href="http://dev.fckeditor.net/ticket/77">#77</a>] If ShiftEnterMode
+			is set to a block tag (p or div), the desired block creation in now enforced, instead
+			of copying the current block (which is still the behavior of the simple enter).</li>
 	</ul>
 	<h3>
Index: /FCKeditor/trunk/editor/_source/classes/fckenterkey.js
===================================================================
--- /FCKeditor/trunk/editor/_source/classes/fckenterkey.js	(revision 207)
+++ /FCKeditor/trunk/editor/_source/classes/fckenterkey.js	(revision 208)
@@ -351,6 +351,7 @@
 					else
 					{
-						// If is a header tag, create a new block element.
-						if ( (/^H[1-6]$/).test( sStartBlockTag ) )
+						// If is a header tag, or we are in a Shift+Enter (#77),
+						// create a new block element.
+						if ( (/^H[1-6]$/).test( sStartBlockTag ) || this._HasShift )
 							eNewBlock = this.Window.document.createElement( blockTag ) ;
 						// Otherwise, duplicate the current block.
